==> huaweicloudsdkrms-3.1.49-py2.py3-none-any.whl: huaweicloudsdkrms/v1/model/resource_schema_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResourceSchemaResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'schema': 'object'
    }

    attribute_map = {
        'type': 'type',
        'schema': 'schema'
    }

    def __init__(self, type=None, schema=None):
        """ResourceSchemaResponse

        The model defined in huaweicloud sdk

        :param type: 资源类型.
        :type type: str
        :param schema: schema 内容.
        :type schema: object
        """
        
        

        self._type = None
        self._schema = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if schema is not None:
            self.schema = schema

    @property
    def type(self):
        """Gets the type of this ResourceSchemaResponse.

        资源类型.

        :return: The type of this ResourceSchemaResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourceSchemaResponse.

        资源类型.

        :param type: The type of this ResourceSchemaResponse.
        :type type: str
        """
        self._type = type

    @property
    def schema(self):
        """Gets the schema of this ResourceSchemaResponse.

        schema 内容.

        :return: The schema of this ResourceSchemaResponse.
        :rtype: object
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this ResourceSchemaResponse.

        schema 内容.

        :param schema: The schema of this ResourceSchemaResponse.
        :type schema: object
        """
        self._schema = schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceSchemaResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrms-3.1.149-py2.py3-none-any.whl: huaweicloudsdkrms/v1/model/resource_schema_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ResourceSchemaResponse:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'type': 'str',
        'schema': 'object'
    }

    attribute_map = {
        'type': 'type',
        'schema': 'schema'
    }

    def __init__(self, type=None, schema=None):
        r"""ResourceSchemaResponse

        The model defined in huaweicloud sdk

        :param type: 资源类型.
        :type type: str
        :param schema: schema 内容.
        :type schema: object
        """
        
        

        self._type = None
        self._schema = None
        self.discriminator = None

        if type is not None:
            self.type = type
        if schema is not None:
            self.schema = schema

    @property
    def type(self):
        r"""Gets the type of this ResourceSchemaResponse.

        资源类型.

        :return: The type of this ResourceSchemaResponse.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        r"""Sets the type of this ResourceSchemaResponse.

        资源类型.

        :param type: The type of this ResourceSchemaResponse.
        :type type: str
        """
        self._type = type

    @property
    def schema(self):
        r"""Gets the schema of this ResourceSchemaResponse.

        schema 内容.

        :return: The schema of this ResourceSchemaResponse.
        :rtype: object
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        r"""Sets the schema of this ResourceSchemaResponse.

        schema 内容.

        :param schema: The schema of this ResourceSchemaResponse.
        :type schema: object
        """
        self._schema = schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceSchemaResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
